# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.revenue_model_metadata import RevenueModelMetadata


class RevenueModelsController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(RevenueModelsController, self).__init__(config, call_back)

    def revenue_models_get(self,
                           id=None,
                           created_at=None,
                           title=None,
                           q=None,
                           order=None,
                           sort=None,
                           page=None,
                           per_page=None):
        """Does a GET request to /revenue_models.

        List Revenue Models

        Args:
            id (string, optional): Filter by ID + Examples     +
                `id=5429b1c369702d2f7c040000`     + use
                `id!=5429b1c369702d2f7c040000` to exclude by ID
            created_at (date, optional): Filter by created at date using times
                in ISO8601 format Note: Range filters can be applied by adding
                a suffix: ‘.gt’, ‘.gte’, ‘.lt’, ‘lte’ (Example:
                expires_at.gte) + Examples     + `2017-01-01T00:00:00-00:00` -
                in ISO8601 format     + `1483228800` - Unix timestamps
            title (string, optional): Filter records by title
            q (string, optional): Filter by keyword
            order (string, optional): Filter by ascending or descending order
                + Examples     + asc     + desc
            sort (string, optional): Sort on the specified field
            page (float, optional): Number of pages to return
            per_page (float, optional): Number of records to return per page

        Returns:
            RevenueModelMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/revenue_models'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'id': id,
            'created_at': created_at,
            'title': title,
            'q': q,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, RevenueModelMetadata.from_dictionary)

        return decoded

    def revenue_models_by_id_get(self,
                                 id):
        """Does a GET request to /revenue_models/{id}.

        View Revenue Model

        Args:
            id (string): ID of the revenue model

        Returns:
            RevenueModelMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/revenue_models/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, RevenueModelMetadata.from_dictionary)

        return decoded



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import unittest
from zypev1.configuration import Configuration
from zypev1.configuration import Environment
from zypev1.zypev_1_client import Zypev1Client


class ControllerTestBase(unittest.TestCase):

    """All test classes inherit from this base class. It abstracts out
    common functionality and configuration variables set up."""

    @classmethod
    def setUpClass(cls):
        """Class method called once before running tests in a test class."""
        cls.request_timeout = 30
        cls.assert_precision = 0.01
        cls.config = ControllerTestBase.create_configuration()
        cls.client = Zypev1Client()

    @staticmethod
    def create_configuration():
        return Configuration()



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from zypev1.models.file_24 import File24
from zypev1.models.thumbnail import Thumbnail


class VideoImport(object):

    """Implementation of the 'VideoImport' model.

    TODO: type model description here.

    Attributes:
        title (string): TODO: type description here.
        video_source_id (string): TODO: type description here.
        id (string): ID of video import
        created_at (string): Timestamp video import was created
        deleted_at (string): Timestamp video was deleted
        updated_at (string): Timestamp of when video was last updated
        description (string): Description of the video import
        duration (float): Length of video import
        episode (float): Episode number
        expires_at (string): Timestamp of when video import expires
        files (list of File24): TODO: type description here.
        keywords (list of string): Keywords for the video import
        published_at (string): Timestamp when video from video import will be
            published
        season (float): TODO: type description here.
        site_id (string): TODO: type description here.
        starts_at (string): TODO: type description here.
        status (string): TODO: type description here.
        thumbnails (list of Thumbnail): TODO: type description here.
        upload_id (string): TODO: type description here.
        video_id (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "title": 'title',
        "video_source_id": 'video_source_id',
        "id": '_id',
        "created_at": 'created_at',
        "deleted_at": 'deleted_at',
        "updated_at": 'updated_at',
        "description": 'description',
        "duration": 'duration',
        "episode": 'episode',
        "expires_at": 'expires_at',
        "files": 'files',
        "keywords": 'keywords',
        "published_at": 'published_at',
        "season": 'season',
        "site_id": 'site_id',
        "starts_at": 'starts_at',
        "status": 'status',
        "thumbnails": 'thumbnails',
        "upload_id": 'upload_id',
        "video_id": 'video_id'
    }

    def __init__(self,
                 title=None,
                 video_source_id=None,
                 id=None,
                 created_at=None,
                 deleted_at=None,
                 updated_at=None,
                 description=None,
                 duration=None,
                 episode=None,
                 expires_at=None,
                 files=None,
                 keywords=None,
                 published_at=None,
                 season=None,
                 site_id=None,
                 starts_at=None,
                 status=None,
                 thumbnails=None,
                 upload_id=None,
                 video_id=None):
        """Constructor for the VideoImport class"""

        # Initialize members of the class
        self.title = title
        self.video_source_id = video_source_id
        self.id = id
        self.created_at = created_at
        self.deleted_at = deleted_at
        self.updated_at = updated_at
        self.description = description
        self.duration = duration
        self.episode = episode
        self.expires_at = expires_at
        self.files = files
        self.keywords = keywords
        self.published_at = published_at
        self.season = season
        self.site_id = site_id
        self.starts_at = starts_at
        self.status = status
        self.thumbnails = thumbnails
        self.upload_id = upload_id
        self.video_id = video_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        title = dictionary.get('title')
        video_source_id = dictionary.get('video_source_id')
        id = dictionary.get('_id')
        created_at = dictionary.get('created_at')
        deleted_at = dictionary.get('deleted_at')
        updated_at = dictionary.get('updated_at')
        description = dictionary.get('description')
        duration = dictionary.get('duration')
        episode = dictionary.get('episode')
        expires_at = dictionary.get('expires_at')
        files = None
        if dictionary.get('files') is not None:
            files = [File24.from_dictionary(x) for x in dictionary.get('files')]
        keywords = dictionary.get('keywords')
        published_at = dictionary.get('published_at')
        season = dictionary.get('season')
        site_id = dictionary.get('site_id')
        starts_at = dictionary.get('starts_at')
        status = dictionary.get('status')
        thumbnails = None
        if dictionary.get('thumbnails') is not None:
            thumbnails = [Thumbnail.from_dictionary(x) for x in dictionary.get('thumbnails')]
        upload_id = dictionary.get('upload_id')
        video_id = dictionary.get('video_id')

        # Return an object of this model
        return cls(title,
                   video_source_id,
                   id,
                   created_at,
                   deleted_at,
                   updated_at,
                   description,
                   duration,
                   episode,
                   expires_at,
                   files,
                   keywords,
                   published_at,
                   season,
                   site_id,
                   starts_at,
                   status,
                   thumbnails,
                   upload_id,
                   video_id)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.zobject_metadata import ZobjectMetadata


class ZobjectController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(ZobjectController, self).__init__(config, call_back)

    def zobjects_get(self,
                     id=None,
                     custom=None,
                     q=None,
                     order=None,
                     sort=None,
                     page=None,
                     per_page=None,
                     zobject_type=None):
        """Does a GET request to /zobjects.

        List Zobject Types

        Args:
            id (string, optional): Filter by ID + Examples     +
                `id=549dc72d636872c09d1f0000`     + use
                `id!=549dc72d636872c09d1f0000` to exclude by ID
            custom (string, optional): Filter records by custom attribues +
                Example: color=blue
            q (string, optional): Filter by keyword
            order (string, optional): Filter by ascending or descending order
                + Examples     + asc     + desc
            sort (string, optional): Sort on the specified field
            page (float, optional): Number of pages to return
            per_page (float, optional): Number of records to return per page
            zobject_type (string, optional): TODO: type description here.

        Returns:
            ZobjectMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/zobjects'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'id': id,
            'custom': custom,
            'q': q,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page,
            'zobject_type': zobject_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ZobjectMetadata.from_dictionary)

        return decoded

    def zobjects_post(self,
                      body,
                      id=None,
                      custom=None,
                      zobject_type=None,
                      page=None,
                      per_page=None,
                      q=None,
                      order=None,
                      sort=None):
        """Does a POST request to /zobjects.

        Create Zobject

        Args:
            body (ZobjectRequest): TODO: type description here.
            id (string, optional): TODO: type description here.
            custom (string, optional): TODO: type description here.
            zobject_type (string, optional): TODO: type description here.
            page (string, optional): TODO: type description here.
            per_page (string, optional): TODO: type description here.
            q (string, optional): TODO: type description here.
            order (string, optional): TODO: type description here.
            sort (string, optional): TODO: type description here.

        Returns:
            ZobjectMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/zobjects'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'id': id,
            'custom': custom,
            'zobject_type': zobject_type,
            'page': page,
            'per_page': per_page,
            'q': q,
            'order': order,
            'sort': sort
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ZobjectMetadata.from_dictionary)

        return decoded

    def zobjects_by_id_get(self,
                           id):
        """Does a GET request to /zobjects/{id}.

        Retrieve Zobject

        Args:
            id (string): ID of the record

        Returns:
            ZobjectMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/zobjects/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ZobjectMetadata.from_dictionary)

        return decoded

    def zobjects_by_id_put(self,
                           id,
                           body):
        """Does a PUT request to /zobjects/{id}.

        Update Zobject

        Args:
            id (string): ID of the record
            body (ZobjectRequest): TODO: type description here.

        Returns:
            ZobjectMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/zobjects/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ZobjectMetadata.from_dictionary)

        return decoded

    def zobjects_by_id_delete(self,
                              id):
        """Does a DELETE request to /zobjects/{id}.

        Delete Zobject

        Args:
            id (string): ID of the record

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/zobjects/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from zypev1.models.embedded_category import EmbeddedCategory
from zypev1.models.image import Image
from zypev1.models.segment import Segment
from zypev1.models.thumbnail import Thumbnail
from zypev1.models.zobject import Zobject


class VideoMetadata(object):

    """Implementation of the 'VideoMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): ID of the record
        created_at (string): Timestamp video was created
        deleted_at (string): Timestamp video was deleted
        updated_at (string): Timestamp of when video was last updated
        on_air (bool): TODO: type description here.
        purchase_price (float): Amount to purchase the video
        purchase_required (bool): Whether or not the video must be purchased
        rating (float): Overall rating of the video
        related_playlist_ids (list of float): IDs of related playlists
        rental_duration (float): Number of days video can be rented
        rental_price (float): Price to rent video
        rental_required (bool): TODO: type description here.
        request_count (float): Number of times a video has be requested
        site_id (string): Site the videos is related to
        status (string): Status of the video. Options are: - created - ready
        crunchyroll_id (string): ID of Crunchyroll source
        hulu_id (string): ID of Hulu source
        mrss_id (string): ID of MRSS source
        kaltura_id (string): ID of Kaltura source
        vimeo_id (string): ID of the Vimeo source
        youtube_id (string): ID of the YouTube source
        thumbnails (list of Thumbnail): TODO: type description here.
        transcoded (bool): TODO: type description here.
        video_zobjects (list of Zobject): TODO: type description here.
        active (bool): TODO: type description here.
        country (string): The country the video was created in
        description (string): Full length description of the video
        short_description (string): Brief description of the video
        disable_at (string): Timestamp of when your video will become
            inactive
        enable_at (string): Timestamp of when your video will become active
        episode (float): Episode number
        season (float): Season number
        featured (bool): TODO: type description here.
        friendly_title (string): The URL friendly title of the video
        keywords (list of string): Keywords for the video
        mature_content (bool): Whether or not the video requires the viewer to
            be 18+ to view
        pass_required (bool): TODO: type description here.
        published_at (string): Timestamp when video was published
        subscription_required (bool): TODO: type description here.
        discovery_url (string): URL where your video can be discovered
        custom_thumbnail_url (string): URL where your custom thumbnail is
            stored
        subscription_ads_enabled (bool): TODO: type description here.
        title (string): Title of the video
        zobject_ids (object): IDs of Zobjects
        custom_attributes (object): Any custom attributes you want to
            attribute to the video
        categories_attributes (list of EmbeddedCategory): TODO: type
            description here.
        segments (list of Segment): TODO: type description here.
        images_attributes (list of Image): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "created_at": 'created_at',
        "deleted_at": 'deleted_at',
        "updated_at": 'updated_at',
        "on_air": 'on_air',
        "purchase_price": 'purchase_price',
        "purchase_required": 'purchase_required',
        "rating": 'rating',
        "related_playlist_ids": 'related_playlist_ids',
        "rental_duration": 'rental_duration',
        "rental_price": 'rental_price',
        "rental_required": 'rental_required',
        "request_count": 'request_count',
        "site_id": 'site_id',
        "status": 'status',
        "crunchyroll_id": 'crunchyroll_id',
        "hulu_id": 'hulu_id',
        "mrss_id": 'mrss_id',
        "kaltura_id": 'kaltura_id',
        "vimeo_id": 'vimeo_id',
        "youtube_id": 'youtube_id',
        "thumbnails": 'thumbnails',
        "transcoded": 'transcoded',
        "video_zobjects": 'video_zobjects',
        "active": 'active',
        "country": 'country',
        "description": 'description',
        "short_description": 'short_description',
        "disable_at": 'disable_at',
        "enable_at": 'enable_at',
        "episode": 'episode',
        "season": 'season',
        "featured": 'featured',
        "friendly_title": 'friendly_title',
        "keywords": 'keywords',
        "mature_content": 'mature_content',
        "pass_required": 'pass_required',
        "published_at": 'published_at',
        "subscription_required": 'subscription_required',
        "discovery_url": 'discovery_url',
        "custom_thumbnail_url": 'custom_thumbnail_url',
        "subscription_ads_enabled": 'subscription_ads_enabled',
        "title": 'title',
        "zobject_ids": 'zobject_ids',
        "custom_attributes": 'custom_attributes',
        "categories_attributes": 'categories_attributes',
        "segments": 'segments',
        "images_attributes": 'images_attributes'
    }

    def __init__(self,
                 id=None,
                 created_at=None,
                 deleted_at=None,
                 updated_at=None,
                 on_air=None,
                 purchase_price=None,
                 purchase_required=None,
                 rating=None,
                 related_playlist_ids=None,
                 rental_duration=None,
                 rental_price=None,
                 rental_required=None,
                 request_count=None,
                 site_id=None,
                 status=None,
                 crunchyroll_id=None,
                 hulu_id=None,
                 mrss_id=None,
                 kaltura_id=None,
                 vimeo_id=None,
                 youtube_id=None,
                 thumbnails=None,
                 transcoded=None,
                 video_zobjects=None,
                 active=None,
                 country=None,
                 description=None,
                 short_description=None,
                 disable_at=None,
                 enable_at=None,
                 episode=None,
                 season=None,
                 featured=None,
                 friendly_title=None,
                 keywords=None,
                 mature_content=None,
                 pass_required=None,
                 published_at=None,
                 subscription_required=None,
                 discovery_url=None,
                 custom_thumbnail_url=None,
                 subscription_ads_enabled=None,
                 title=None,
                 zobject_ids=None,
                 custom_attributes=None,
                 categories_attributes=None,
                 segments=None,
                 images_attributes=None):
        """Constructor for the VideoMetadata class"""

        # Initialize members of the class
        self.id = id
        self.created_at = created_at
        self.deleted_at = deleted_at
        self.updated_at = updated_at
        self.on_air = on_air
        self.purchase_price = purchase_price
        self.purchase_required = purchase_required
        self.rating = rating
        self.related_playlist_ids = related_playlist_ids
        self.rental_duration = rental_duration
        self.rental_price = rental_price
        self.rental_required = rental_required
        self.request_count = request_count
        self.site_id = site_id
        self.status = status
        self.crunchyroll_id = crunchyroll_id
        self.hulu_id = hulu_id
        self.mrss_id = mrss_id
        self.kaltura_id = kaltura_id
        self.vimeo_id = vimeo_id
        self.youtube_id = youtube_id
        self.thumbnails = thumbnails
        self.transcoded = transcoded
        self.video_zobjects = video_zobjects
        self.active = active
        self.country = country
        self.description = description
        self.short_description = short_description
        self.disable_at = disable_at
        self.enable_at = enable_at
        self.episode = episode
        self.season = season
        self.featured = featured
        self.friendly_title = friendly_title
        self.keywords = keywords
        self.mature_content = mature_content
        self.pass_required = pass_required
        self.published_at = published_at
        self.subscription_required = subscription_required
        self.discovery_url = discovery_url
        self.custom_thumbnail_url = custom_thumbnail_url
        self.subscription_ads_enabled = subscription_ads_enabled
        self.title = title
        self.zobject_ids = zobject_ids
        self.custom_attributes = custom_attributes
        self.categories_attributes = categories_attributes
        self.segments = segments
        self.images_attributes = images_attributes

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        created_at = dictionary.get('created_at')
        deleted_at = dictionary.get('deleted_at')
        updated_at = dictionary.get('updated_at')
        on_air = dictionary.get('on_air')
        purchase_price = dictionary.get('purchase_price')
        purchase_required = dictionary.get('purchase_required')
        rating = dictionary.get('rating')
        related_playlist_ids = dictionary.get('related_playlist_ids')
        rental_duration = dictionary.get('rental_duration')
        rental_price = dictionary.get('rental_price')
        rental_required = dictionary.get('rental_required')
        request_count = dictionary.get('request_count')
        site_id = dictionary.get('site_id')
        status = dictionary.get('status')
        crunchyroll_id = dictionary.get('crunchyroll_id')
        hulu_id = dictionary.get('hulu_id')
        mrss_id = dictionary.get('mrss_id')
        kaltura_id = dictionary.get('kaltura_id')
        vimeo_id = dictionary.get('vimeo_id')
        youtube_id = dictionary.get('youtube_id')
        thumbnails = None
        if dictionary.get('thumbnails') is not None:
            thumbnails = [Thumbnail.from_dictionary(x) for x in dictionary.get('thumbnails')]
        transcoded = dictionary.get('transcoded')
        video_zobjects = None
        if dictionary.get('video_zobjects') is not None:
            video_zobjects = [Zobject.from_dictionary(x) for x in dictionary.get('video_zobjects')]
        active = dictionary.get('active')
        country = dictionary.get('country')
        description = dictionary.get('description')
        short_description = dictionary.get('short_description')
        disable_at = dictionary.get('disable_at')
        enable_at = dictionary.get('enable_at')
        episode = dictionary.get('episode')
        season = dictionary.get('season')
        featured = dictionary.get('featured')
        friendly_title = dictionary.get('friendly_title')
        keywords = dictionary.get('keywords')
        mature_content = dictionary.get('mature_content')
        pass_required = dictionary.get('pass_required')
        published_at = dictionary.get('published_at')
        subscription_required = dictionary.get('subscription_required')
        discovery_url = dictionary.get('discovery_url')
        custom_thumbnail_url = dictionary.get('custom_thumbnail_url')
        subscription_ads_enabled = dictionary.get('subscription_ads_enabled')
        title = dictionary.get('title')
        zobject_ids = dictionary.get('zobject_ids')
        custom_attributes = dictionary.get('custom_attributes')
        categories_attributes = None
        if dictionary.get('categories_attributes') is not None:
            categories_attributes = [EmbeddedCategory.from_dictionary(x) for x in dictionary.get('categories_attributes')]
        segments = None
        if dictionary.get('segments') is not None:
            segments = [Segment.from_dictionary(x) for x in dictionary.get('segments')]
        images_attributes = None
        if dictionary.get('images_attributes') is not None:
            images_attributes = [Image.from_dictionary(x) for x in dictionary.get('images_attributes')]

        # Return an object of this model
        return cls(id,
                   created_at,
                   deleted_at,
                   updated_at,
                   on_air,
                   purchase_price,
                   purchase_required,
                   rating,
                   related_playlist_ids,
                   rental_duration,
                   rental_price,
                   rental_required,
                   request_count,
                   site_id,
                   status,
                   crunchyroll_id,
                   hulu_id,
                   mrss_id,
                   kaltura_id,
                   vimeo_id,
                   youtube_id,
                   thumbnails,
                   transcoded,
                   video_zobjects,
                   active,
                   country,
                   description,
                   short_description,
                   disable_at,
                   enable_at,
                   episode,
                   season,
                   featured,
                   friendly_title,
                   keywords,
                   mature_content,
                   pass_required,
                   published_at,
                   subscription_required,
                   discovery_url,
                   custom_thumbnail_url,
                   subscription_ads_enabled,
                   title,
                   zobject_ids,
                   custom_attributes,
                   categories_attributes,
                   segments,
                   images_attributes)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ZobjectAttributeMetadata(object):

    """Implementation of the 'ZobjectAttributeMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): ID of the record
        created_at (string): TODO: type description here.
        updated_at (string): TODO: type description here.
        description (string): Description of the Zobject Type custom
            attribute
        field_name (string): Name of the Zobject Type custom attribute
        field_type (string): type of the Zobject Type custom attribute

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "created_at": 'created_at',
        "updated_at": 'updated_at',
        "description": 'description',
        "field_name": 'field_name',
        "field_type": 'field_type'
    }

    def __init__(self,
                 id=None,
                 created_at=None,
                 updated_at=None,
                 description=None,
                 field_name=None,
                 field_type=None):
        """Constructor for the ZobjectAttributeMetadata class"""

        # Initialize members of the class
        self.id = id
        self.created_at = created_at
        self.updated_at = updated_at
        self.description = description
        self.field_name = field_name
        self.field_type = field_type

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        created_at = dictionary.get('created_at')
        updated_at = dictionary.get('updated_at')
        description = dictionary.get('description')
        field_name = dictionary.get('field_name')
        field_type = dictionary.get('field_type')

        # Return an object of this model
        return cls(id,
                   created_at,
                   updated_at,
                   description,
                   field_name,
                   field_type)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class RedemptionCode45(object):

    """Implementation of the 'redemption_code45' model.

    TODO: type model description here.

    Attributes:
        code (string): TODO: type description here.
        expiration_date (string): TODO: type description here.
        video_id (string): TODO: type description here.
        pass_plan_id (string): TODO: type description here.
        plan_id (string): TODO: type description here.
        playlist_id (string): TODO: type description here.
        transaction_id (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "code": 'code',
        "expiration_date": 'expiration_date',
        "video_id": 'video_id',
        "pass_plan_id": 'pass_plan_id',
        "plan_id": 'plan_id',
        "playlist_id": 'playlist_id',
        "transaction_id": 'transaction_id'
    }

    def __init__(self,
                 code=None,
                 expiration_date=None,
                 video_id=None,
                 pass_plan_id=None,
                 plan_id=None,
                 playlist_id=None,
                 transaction_id=None):
        """Constructor for the RedemptionCode45 class"""

        # Initialize members of the class
        self.code = code
        self.expiration_date = expiration_date
        self.video_id = video_id
        self.pass_plan_id = pass_plan_id
        self.plan_id = plan_id
        self.playlist_id = playlist_id
        self.transaction_id = transaction_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        code = dictionary.get('code')
        expiration_date = dictionary.get('expiration_date')
        video_id = dictionary.get('video_id')
        pass_plan_id = dictionary.get('pass_plan_id')
        plan_id = dictionary.get('plan_id')
        playlist_id = dictionary.get('playlist_id')
        transaction_id = dictionary.get('transaction_id')

        # Return an object of this model
        return cls(code,
                   expiration_date,
                   video_id,
                   pass_plan_id,
                   plan_id,
                   playlist_id,
                   transaction_id)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.o_auth import OAuth
from zypev1.models.o_auth_status import OAuthStatus


class OAuthController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(OAuthController, self).__init__(config, call_back)

    def oauth_token_post_2(self,
                           client_id,
                           client_secret,
                           refresh_token,
                           grant_type,
                           body):
        """Does a POST request to /oauth/token.

        Refreshing Access Token

        Args:
            client_id (string): The client ID for your Zype application
            client_secret (string): The client secret for your Zype
                application
            refresh_token (string): Token to use to refresh
            grant_type (string): Must use `refresh_token`
            body (OAuthRefreshRequest): TODO: type description here.

        Returns:
            OAuth: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/oauth/token'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'client_id': client_id,
            'client_secret': client_secret,
            'refresh_token': refresh_token,
            'grant_type': grant_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, OAuth.from_dictionary)

        return decoded

    def oauth_token_status_post(self,
                                access_token):
        """Does a POST request to /oauth/token/status.

        Access Token Status

        Args:
            access_token (string): Access Token created via OAuth

        Returns:
            OAuthStatus: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/oauth/token/status'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'access_token': access_token
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, OAuthStatus.from_dictionary)

        return decoded



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from zypev1.models.styles import Styles


class PictureMetadata(object):

    """Implementation of the 'PictureMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        styles (Styles): TODO: type description here.
        content_type (string): TODO: type description here.
        updated_at (string): TODO: type description here.
        url (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "styles": 'styles',
        "content_type": 'content_type',
        "updated_at": 'updated_at',
        "url": 'url'
    }

    def __init__(self,
                 id=None,
                 styles=None,
                 content_type=None,
                 updated_at=None,
                 url=None):
        """Constructor for the PictureMetadata class"""

        # Initialize members of the class
        self.id = id
        self.styles = styles
        self.content_type = content_type
        self.updated_at = updated_at
        self.url = url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        styles = Styles.from_dictionary(dictionary.get('styles')) if dictionary.get('styles') else None
        content_type = dictionary.get('content_type')
        updated_at = dictionary.get('updated_at')
        url = dictionary.get('url')

        # Return an object of this model
        return cls(id,
                   styles,
                   content_type,
                   updated_at,
                   url)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from zypev1.models.redemption_code_45 import RedemptionCode45


class RedemptionCodeRequest(object):

    """Implementation of the 'RedemptionCodeRequest' model.

    TODO: type model description here.

    Attributes:
        redemption_code (RedemptionCode45): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "redemption_code": 'redemption_code'
    }

    def __init__(self,
                 redemption_code=None):
        """Constructor for the RedemptionCodeRequest class"""

        # Initialize members of the class
        self.redemption_code = redemption_code

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        redemption_code = RedemptionCode45.from_dictionary(dictionary.get('redemption_code')) if dictionary.get('redemption_code') else None

        # Return an object of this model
        return cls(redemption_code)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from zypev1.api_helper import APIHelper
from zypev1.controllers.playlist_entitlements_controller import PlaylistEntitlementsController


class PlaylistEntitlementsControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(PlaylistEntitlementsControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = PlaylistEntitlementsController(cls.config, cls.response_catcher)

    # Testcase for testing endpoint Delete a Playlist Entitlement
    def test_delete_a_playlist_entitlement_1(self):
        # Parameters for the API call
        consumer_id = '5a0474c6aff38b1df4000036'
        id = '574decf509838854f1000183'

        # Perform the API call through the SDK function
        self.controller.consumers_playlists_by_consumer_id_and_id_delete(consumer_id, id)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 204)

        # Test headers
        expected_headers = {}
        expected_headers['content-type'] = None

        self.assertTrue(TestHelper.match_headers(expected_headers, self.response_catcher.response.headers))





# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class TransactionMetadata(object):

    """Implementation of the 'TransactionMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        created_at (string): TODO: type description here.
        expires_at (string): TODO: type description here.
        site_id (string): TODO: type description here.
        status (string): TODO: type description here.
        stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e (string): TODO:
            type description here.
        updated_at (string): TODO: type description here.
        amount (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "created_at": 'created_at',
        "expires_at": 'expires_at',
        "site_id": 'site_id',
        "status": 'status',
        "stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e": 'stripe_id: ch_1AztEoChyLVkXdp8yRoQlZ5e',
        "updated_at": 'updated_at',
        "amount": 'amount'
    }

    def __init__(self,
                 id=None,
                 created_at=None,
                 expires_at=None,
                 site_id=None,
                 status=None,
                 stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e=None,
                 updated_at=None,
                 amount=None):
        """Constructor for the TransactionMetadata class"""

        # Initialize members of the class
        self.id = id
        self.created_at = created_at
        self.expires_at = expires_at
        self.site_id = site_id
        self.status = status
        self.stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e = stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e
        self.updated_at = updated_at
        self.amount = amount

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        created_at = dictionary.get('created_at')
        expires_at = dictionary.get('expires_at')
        site_id = dictionary.get('site_id')
        status = dictionary.get('status')
        stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e = dictionary.get('stripe_id: ch_1AztEoChyLVkXdp8yRoQlZ5e')
        updated_at = dictionary.get('updated_at')
        amount = dictionary.get('amount')

        # Return an object of this model
        return cls(id,
                   created_at,
                   expires_at,
                   site_id,
                   status,
                   stripe_id_ch_1_azt_eo_chy_l_vk_xdp_8_y_ro_ql_z_5_e,
                   updated_at,
                   amount)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.device_pin import DevicePin
from zypev1.models.consumer_metadata import ConsumerMetadata


class DeviceLinkingController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(DeviceLinkingController, self).__init__(config, call_back)

    def pin_acquire_post(self,
                         linked_device_id,
                         mtype,
                         body):
        """Does a POST request to /pin/acquire.

        Acquire Device Pin

        Args:
            linked_device_id (string): Unique ID of the user's device
            mtype (string): type of Device to link to
            body (object): TODO: type description here.

        Returns:
            DevicePin: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/pin/acquire'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'linked_device_id': linked_device_id,
            'type': mtype
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, DevicePin.from_dictionary)

        return decoded

    def pin_status_get(self,
                       linked_device_id):
        """Does a GET request to /pin/status.

        Retrieve Device Pin

        Args:
            linked_device_id (string): Unique ID of the user's device

        Returns:
            DevicePin: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/pin/status'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'linked_device_id': linked_device_id
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, DevicePin.from_dictionary)

        return decoded

    def pin_link_put(self,
                     consumer_id,
                     pin):
        """Does a PUT request to /pin/link.

        Link

        Args:
            consumer_id (string): ID of consumer to link device to
            pin (string): The value for the acquired device pin

        Returns:
            ConsumerMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/pin/link'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'consumer_id': consumer_id,
            'pin': pin
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ConsumerMetadata.from_dictionary)

        return decoded

    def pin_unlink_put(self,
                       consumer_id,
                       pin):
        """Does a PUT request to /pin/unlink.

        Unlink

        Args:
            consumer_id (string): ID of consumer to link device to
            pin (string): The value for the acquired device pin

        Returns:
            ConsumerMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/pin/unlink'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'consumer_id': consumer_id,
            'pin': pin
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ConsumerMetadata.from_dictionary)

        return decoded



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Category(object):

    """Implementation of the 'Category' model.

    TODO: type model description here.

    Attributes:
        title (string): Title of the category assigned to the video
        friendly_title (string): URL friendly title

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "title": 'title',
        "friendly_title": 'friendly_title'
    }

    def __init__(self,
                 title=None,
                 friendly_title=None):
        """Constructor for the Category class"""

        # Initialize members of the class
        self.title = title
        self.friendly_title = friendly_title

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        title = dictionary.get('title')
        friendly_title = dictionary.get('friendly_title')

        # Return an object of this model
        return cls(title,
                   friendly_title)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AdTagMetadata(object):

    """Implementation of the 'AdTagMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        created_at (string): TODO: type description here.
        site_id (string): TODO: type description here.
        name (string): TODO: type description here.
        active (string): TODO: type description here.
        network_key (string): TODO: type description here.
        device_category_id (string): TODO: type description here.
        device_id (string): ID of device to display ad on
        disabled (bool): TODO: type description here.
        interval_count (string): How many times a video or videos in a
            collection will play before a single user gets an ad
        interval_seconds (string): TODO: type description here.
        revenue_partner_id (string): TODO: type description here.
        scope (string): Optional. Whether interval_count applies to single
            video (‘video’) or a collection of videos (‘library’).
        tag (string): URL of the ad
        vmap (string): TODO: type description here.
        mtype (string): One of “AdTag::Vast” or “AdTag::Googima”

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "created_at": 'created_at',
        "site_id": 'site_id',
        "name": 'name',
        "active": 'active',
        "network_key": 'network_key',
        "device_category_id": 'device_category_id',
        "device_id": 'device_id',
        "disabled": 'disabled',
        "interval_count": 'interval_count',
        "interval_seconds": 'interval_seconds',
        "revenue_partner_id": 'revenue_partner_id',
        "scope": 'scope',
        "tag": 'tag',
        "vmap": 'vmap',
        "mtype": '_type'
    }

    def __init__(self,
                 id=None,
                 created_at=None,
                 site_id=None,
                 name=None,
                 active=None,
                 network_key=None,
                 device_category_id=None,
                 device_id=None,
                 disabled=None,
                 interval_count=None,
                 interval_seconds=None,
                 revenue_partner_id=None,
                 scope=None,
                 tag=None,
                 vmap=None,
                 mtype=None):
        """Constructor for the AdTagMetadata class"""

        # Initialize members of the class
        self.id = id
        self.created_at = created_at
        self.site_id = site_id
        self.name = name
        self.active = active
        self.network_key = network_key
        self.device_category_id = device_category_id
        self.device_id = device_id
        self.disabled = disabled
        self.interval_count = interval_count
        self.interval_seconds = interval_seconds
        self.revenue_partner_id = revenue_partner_id
        self.scope = scope
        self.tag = tag
        self.vmap = vmap
        self.mtype = mtype

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        created_at = dictionary.get('created_at')
        site_id = dictionary.get('site_id')
        name = dictionary.get('name')
        active = dictionary.get('active')
        network_key = dictionary.get('network_key')
        device_category_id = dictionary.get('device_category_id')
        device_id = dictionary.get('device_id')
        disabled = dictionary.get('disabled')
        interval_count = dictionary.get('interval_count')
        interval_seconds = dictionary.get('interval_seconds')
        revenue_partner_id = dictionary.get('revenue_partner_id')
        scope = dictionary.get('scope')
        tag = dictionary.get('tag')
        vmap = dictionary.get('vmap')
        mtype = dictionary.get('_type')

        # Return an object of this model
        return cls(id,
                   created_at,
                   site_id,
                   name,
                   active,
                   network_key,
                   device_category_id,
                   device_id,
                   disabled,
                   interval_count,
                   interval_seconds,
                   revenue_partner_id,
                   scope,
                   tag,
                   vmap,
                   mtype)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.video_source_metadata import VideoSourceMetadata


class VideoSourcesController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(VideoSourcesController, self).__init__(config, call_back)

    def video_sources_get(self,
                          id=None,
                          mtype=None,
                          q=None,
                          order=None,
                          sort=None,
                          page=None,
                          per_page=None):
        """Does a GET request to /video_sources.

        List Video Sources

        Args:
            id (string, optional): Filter by id + Examples     +
                `id=5992f328ce593000ef000008`     + use
                `id!=5992f328ce593000ef000008` to exclude by id
            mtype (string, optional): Filter by title + Examples     + hulu   
                + youtube     + crunchyroll
            q (string, optional): Filter by keyword
            order (string, optional): Filter by ascending or descending order
                + Examples     + asc     + desc
            sort (string, optional): Sort on the specified field
            page (float, optional): Number of pages to return
            per_page (float, optional): Number of records to return per page

        Returns:
            list of VideoSourceMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/video_sources'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'id': id,
            'type': mtype,
            'q': q,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoSourceMetadata.from_dictionary)

        return decoded

    def video_sources_post(self,
                           body,
                           mtype=None,
                           id=None,
                           order=None,
                           sort=None,
                           page=None,
                           per_page=None,
                           q=None):
        """Does a POST request to /video_sources.

        Only MRSS video sources may be created via the API at this time.

        Args:
            body (VideoSourceRequest): TODO: type description here.
            mtype (string, optional): TODO: type description here.
            id (string, optional): TODO: type description here.
            order (string, optional): TODO: type description here.
            sort (string, optional): TODO: type description here.
            page (string, optional): TODO: type description here.
            per_page (string, optional): TODO: type description here.
            q (string, optional): TODO: type description here.

        Returns:
            VideoSourceMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/video_sources'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'type': mtype,
            'id': id,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page,
            'q': q
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoSourceMetadata.from_dictionary)

        return decoded

    def video_sources_by_id_get(self,
                                id):
        """Does a GET request to /video_sources/{id}.

        View Video Source

        Args:
            id (string): ID of video source

        Returns:
            VideoSourceMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/video_sources/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoSourceMetadata.from_dictionary)

        return decoded

    def video_sources_by_id_put(self,
                                id,
                                body):
        """Does a PUT request to /video_sources/{id}.

        Update Video Source

        Args:
            id (string): ID of video source
            body (VideoSourceRequest): TODO: type description here.

        Returns:
            VideoSourceMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/video_sources/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoSourceMetadata.from_dictionary)

        return decoded

    def video_sources_by_id_delete(self,
                                   id):
        """Does a DELETE request to /video_sources/{id}.

        Delete a Video Source

        Args:
            id (string): ID of video source

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/video_sources/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.video_favorite_metadata import VideoFavoriteMetadata


class VideoFavoritesController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(VideoFavoritesController, self).__init__(config, call_back)

    def consumers_video_favorites_by_consumer_id_get(self,
                                                     consumer_id):
        """Does a GET request to /consumers/{consumer_id}/video_favorites.

        List Video Favorites

        Args:
            consumer_id (string): ID of consumer

        Returns:
            VideoFavoriteMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{consumer_id}/video_favorites'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'consumer_id': {'value': consumer_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoFavoriteMetadata.from_dictionary)

        return decoded

    def consumers_video_favorites_by_consumer_id_post(self,
                                                      body,
                                                      consumer_id):
        """Does a POST request to /consumers/{consumer_id}/video_favorites.

        Create Video Favorite

        Args:
            body (VideoFavoriteRequest): TODO: type description here.
            consumer_id (string): TODO: type description here.

        Returns:
            VideoFavoriteMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{consumer_id}/video_favorites'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'consumer_id': {'value': consumer_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoFavoriteMetadata.from_dictionary)

        return decoded

    def consumers_video_favorites_by_consumer_id_and_video_id_delete(self,
                                                                     consumer_id,
                                                                     video_id):
        """Does a DELETE request to /consumers/{consumer_id}/video_favorites/{video_id}.

        Delete Video Favorite

        Args:
            consumer_id (string): ID of consumer
            video_id (string): ID of video

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{consumer_id}/video_favorites/{video_id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'consumer_id': {'value': consumer_id, 'encode': True},
            'video_id': {'value': video_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from zypev1.models.zobject_attributes import ZobjectAttributes


class ZobjectTypeMetadata(object):

    """Implementation of the 'ZobjectTypeMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): ID of the record
        created_at (string): TODO: type description here.
        site_id (string): TODO: type description here.
        updated_at (string): TODO: type description here.
        zobject_count (string): Number of Zobjects created with this Zobject
            Type
        zobject_attributes (ZobjectAttributes): TODO: type description here.
        description (string): Description of the Zobject Type
        title (string): Title of the Zobject Type (must be unique)
        videos_enabled (bool): Indicates whether videos can be associated with
            instances of the Zobject Type

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "created_at": 'created_at',
        "site_id": 'site_id',
        "updated_at": 'updated_at',
        "zobject_count": 'zobject_count',
        "zobject_attributes": 'zobject_attributes',
        "description": 'description',
        "title": 'title',
        "videos_enabled": 'videos_enabled'
    }

    def __init__(self,
                 id=None,
                 created_at=None,
                 site_id=None,
                 updated_at=None,
                 zobject_count=None,
                 zobject_attributes=None,
                 description=None,
                 title=None,
                 videos_enabled=None):
        """Constructor for the ZobjectTypeMetadata class"""

        # Initialize members of the class
        self.id = id
        self.created_at = created_at
        self.site_id = site_id
        self.updated_at = updated_at
        self.zobject_count = zobject_count
        self.zobject_attributes = zobject_attributes
        self.description = description
        self.title = title
        self.videos_enabled = videos_enabled

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        created_at = dictionary.get('created_at')
        site_id = dictionary.get('site_id')
        updated_at = dictionary.get('updated_at')
        zobject_count = dictionary.get('zobject_count')
        zobject_attributes = ZobjectAttributes.from_dictionary(dictionary.get('zobject_attributes')) if dictionary.get('zobject_attributes') else None
        description = dictionary.get('description')
        title = dictionary.get('title')
        videos_enabled = dictionary.get('videos_enabled')

        # Return an object of this model
        return cls(id,
                   created_at,
                   site_id,
                   updated_at,
                   zobject_count,
                   zobject_attributes,
                   description,
                   title,
                   videos_enabled)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OAuth(object):

    """Implementation of the 'OAuth' model.

    TODO: type model description here.

    Attributes:
        access_token (string): TODO: type description here.
        token_type (string): TODO: type description here.
        expires_in (float): TODO: type description here.
        refresh_token (string): TODO: type description here.
        scope (string): TODO: type description here.
        created_at (float): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "access_token": 'access_token',
        "token_type": 'token_type',
        "expires_in": 'expires_in',
        "refresh_token": 'refresh_token',
        "scope": 'scope',
        "created_at": 'created_at'
    }

    def __init__(self,
                 access_token=None,
                 token_type=None,
                 expires_in=None,
                 refresh_token=None,
                 scope=None,
                 created_at=None):
        """Constructor for the OAuth class"""

        # Initialize members of the class
        self.access_token = access_token
        self.token_type = token_type
        self.expires_in = expires_in
        self.refresh_token = refresh_token
        self.scope = scope
        self.created_at = created_at

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        access_token = dictionary.get('access_token')
        token_type = dictionary.get('token_type')
        expires_in = dictionary.get('expires_in')
        refresh_token = dictionary.get('refresh_token')
        scope = dictionary.get('scope')
        created_at = dictionary.get('created_at')

        # Return an object of this model
        return cls(access_token,
                   token_type,
                   expires_in,
                   refresh_token,
                   scope,
                   created_at)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from zypev1.models.geography import Geography


class ContentRuleMetadata(object):

    """Implementation of the 'ContentRuleMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        created_at (string): 06-30T10:13:14.555-04:00
        updated_at (string): TODO: type description here.
        enabled (bool): TODO: type description here.
        geographies (list of Geography): TODO: type description here.
        name (string): TODO: type description here.
        policy (string): TODO: type description here.
        priority (string): TODO: type description here.
        stackable (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "created_at": 'created_at',
        "updated_at": 'updated_at',
        "enabled": 'enabled',
        "geographies": 'geographies',
        "name": 'name',
        "policy": 'policy',
        "priority": 'priority',
        "stackable": 'stackable'
    }

    def __init__(self,
                 id=None,
                 created_at=None,
                 updated_at=None,
                 enabled=None,
                 geographies=None,
                 name=None,
                 policy=None,
                 priority=None,
                 stackable=None):
        """Constructor for the ContentRuleMetadata class"""

        # Initialize members of the class
        self.id = id
        self.created_at = created_at
        self.updated_at = updated_at
        self.enabled = enabled
        self.geographies = geographies
        self.name = name
        self.policy = policy
        self.priority = priority
        self.stackable = stackable

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        created_at = dictionary.get('created_at')
        updated_at = dictionary.get('updated_at')
        enabled = dictionary.get('enabled')
        geographies = None
        if dictionary.get('geographies') is not None:
            geographies = [Geography.from_dictionary(x) for x in dictionary.get('geographies')]
        name = dictionary.get('name')
        policy = dictionary.get('policy')
        priority = dictionary.get('priority')
        stackable = dictionary.get('stackable')

        # Return an object of this model
        return cls(id,
                   created_at,
                   updated_at,
                   enabled,
                   geographies,
                   name,
                   policy,
                   priority,
                   stackable)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CategoryMetadata(object):

    """Implementation of the 'CategoryMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): ID of the category assigned to the video if you are
            updating its values
        created_at (string): Timestamp category was created
        updated_at (string): Timestamp of when category was last updated
        values (list of string): List of values you wish to add to the
            category. Must exist in the main Category first
        title (string): Title of the category assigned to the video
        friendly_title (string): URL friendly title

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "created_at": 'created_at',
        "updated_at": 'updated_at',
        "values": 'values',
        "title": 'title',
        "friendly_title": 'friendly_title'
    }

    def __init__(self,
                 id=None,
                 created_at=None,
                 updated_at=None,
                 values=None,
                 title=None,
                 friendly_title=None):
        """Constructor for the CategoryMetadata class"""

        # Initialize members of the class
        self.id = id
        self.created_at = created_at
        self.updated_at = updated_at
        self.values = values
        self.title = title
        self.friendly_title = friendly_title

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        created_at = dictionary.get('created_at')
        updated_at = dictionary.get('updated_at')
        values = dictionary.get('values')
        title = dictionary.get('title')
        friendly_title = dictionary.get('friendly_title')

        # Return an object of this model
        return cls(id,
                   created_at,
                   updated_at,
                   values,
                   title,
                   friendly_title)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from zypev1.models.embedded_category import EmbeddedCategory
from zypev1.models.image import Image
from zypev1.models.segment import Segment


class Video(object):

    """Implementation of the 'Video' model.

    TODO: type model description here.

    Attributes:
        active (bool): TODO: type description here.
        country (string): The country the video was created in
        description (string): Full length description of the video
        short_description (string): Brief description of the video
        disable_at (string): Timestamp of when your video will become
            inactive
        enable_at (string): Timestamp of when your video will become active
        episode (float): Episode number
        season (float): Season number
        featured (bool): TODO: type description here.
        friendly_title (string): The URL friendly title of the video
        keywords (list of string): Keywords for the video
        mature_content (bool): Whether or not the video requires the viewer to
            be 18+ to view
        pass_required (bool): TODO: type description here.
        published_at (string): Timestamp when video was published
        subscription_required (bool): TODO: type description here.
        discovery_url (string): URL where your video can be discovered
        custom_thumbnail_url (string): URL where your custom thumbnail is
            stored
        subscription_ads_enabled (bool): TODO: type description here.
        title (string): Title of the video
        zobject_ids (object): IDs of Zobjects
        custom_attributes (object): Any custom attributes you want to
            attribute to the video
        categories_attributes (list of EmbeddedCategory): TODO: type
            description here.
        segments (list of Segment): TODO: type description here.
        images_attributes (list of Image): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "active": 'active',
        "country": 'country',
        "description": 'description',
        "short_description": 'short_description',
        "disable_at": 'disable_at',
        "enable_at": 'enable_at',
        "episode": 'episode',
        "season": 'season',
        "featured": 'featured',
        "friendly_title": 'friendly_title',
        "keywords": 'keywords',
        "mature_content": 'mature_content',
        "pass_required": 'pass_required',
        "published_at": 'published_at',
        "subscription_required": 'subscription_required',
        "discovery_url": 'discovery_url',
        "custom_thumbnail_url": 'custom_thumbnail_url',
        "subscription_ads_enabled": 'subscription_ads_enabled',
        "title": 'title',
        "zobject_ids": 'zobject_ids',
        "custom_attributes": 'custom_attributes',
        "categories_attributes": 'categories_attributes',
        "segments": 'segments',
        "images_attributes": 'images_attributes'
    }

    def __init__(self,
                 active=None,
                 country=None,
                 description=None,
                 short_description=None,
                 disable_at=None,
                 enable_at=None,
                 episode=None,
                 season=None,
                 featured=None,
                 friendly_title=None,
                 keywords=None,
                 mature_content=None,
                 pass_required=None,
                 published_at=None,
                 subscription_required=None,
                 discovery_url=None,
                 custom_thumbnail_url=None,
                 subscription_ads_enabled=None,
                 title=None,
                 zobject_ids=None,
                 custom_attributes=None,
                 categories_attributes=None,
                 segments=None,
                 images_attributes=None):
        """Constructor for the Video class"""

        # Initialize members of the class
        self.active = active
        self.country = country
        self.description = description
        self.short_description = short_description
        self.disable_at = disable_at
        self.enable_at = enable_at
        self.episode = episode
        self.season = season
        self.featured = featured
        self.friendly_title = friendly_title
        self.keywords = keywords
        self.mature_content = mature_content
        self.pass_required = pass_required
        self.published_at = published_at
        self.subscription_required = subscription_required
        self.discovery_url = discovery_url
        self.custom_thumbnail_url = custom_thumbnail_url
        self.subscription_ads_enabled = subscription_ads_enabled
        self.title = title
        self.zobject_ids = zobject_ids
        self.custom_attributes = custom_attributes
        self.categories_attributes = categories_attributes
        self.segments = segments
        self.images_attributes = images_attributes

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        active = dictionary.get('active')
        country = dictionary.get('country')
        description = dictionary.get('description')
        short_description = dictionary.get('short_description')
        disable_at = dictionary.get('disable_at')
        enable_at = dictionary.get('enable_at')
        episode = dictionary.get('episode')
        season = dictionary.get('season')
        featured = dictionary.get('featured')
        friendly_title = dictionary.get('friendly_title')
        keywords = dictionary.get('keywords')
        mature_content = dictionary.get('mature_content')
        pass_required = dictionary.get('pass_required')
        published_at = dictionary.get('published_at')
        subscription_required = dictionary.get('subscription_required')
        discovery_url = dictionary.get('discovery_url')
        custom_thumbnail_url = dictionary.get('custom_thumbnail_url')
        subscription_ads_enabled = dictionary.get('subscription_ads_enabled')
        title = dictionary.get('title')
        zobject_ids = dictionary.get('zobject_ids')
        custom_attributes = dictionary.get('custom_attributes')
        categories_attributes = None
        if dictionary.get('categories_attributes') is not None:
            categories_attributes = [EmbeddedCategory.from_dictionary(x) for x in dictionary.get('categories_attributes')]
        segments = None
        if dictionary.get('segments') is not None:
            segments = [Segment.from_dictionary(x) for x in dictionary.get('segments')]
        images_attributes = None
        if dictionary.get('images_attributes') is not None:
            images_attributes = [Image.from_dictionary(x) for x in dictionary.get('images_attributes')]

        # Return an object of this model
        return cls(active,
                   country,
                   description,
                   short_description,
                   disable_at,
                   enable_at,
                   episode,
                   season,
                   featured,
                   friendly_title,
                   keywords,
                   mature_content,
                   pass_required,
                   published_at,
                   subscription_required,
                   discovery_url,
                   custom_thumbnail_url,
                   subscription_ads_enabled,
                   title,
                   zobject_ids,
                   custom_attributes,
                   categories_attributes,
                   segments,
                   images_attributes)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.decorators import lazy_property
from zypev1.configuration import Configuration
from zypev1.configuration import Environment
from zypev1.controllers.videos_controller import VideosController
from zypev1.controllers.playlists_controller import PlaylistsController
from zypev1.controllers.managing_playlist_relationships_controller\
    import ManagingPlaylistRelationshipsController
from zypev1.controllers.categories_controller import CategoriesController
from zypev1.controllers.apps_controller import AppsController
from zypev1.controllers.devices_controller import DevicesController
from zypev1.controllers.device_categories_controller\
    import DeviceCategoriesController
from zypev1.controllers.players_controller import PlayersController
from zypev1.controllers.master_manifests_controller\
    import MasterManifestsController
from zypev1.controllers.segments_controller import SegmentsController
from zypev1.controllers.video_imports_controller import VideoImportsController
from zypev1.controllers.video_sources_controller import VideoSourcesController
from zypev1.controllers.category_content_rules_controller\
    import CategoryContentRulesController
from zypev1.controllers.playlist_content_rules_controller\
    import PlaylistContentRulesController
from zypev1.controllers.video_content_rules_controller\
    import VideoContentRulesController
from zypev1.controllers.consumers_controller import ConsumersController
from zypev1.controllers.device_linking_controller\
    import DeviceLinkingController
from zypev1.controllers.o_auth_controller import OAuthController
from zypev1.controllers.video_entitlements_controller\
    import VideoEntitlementsController
from zypev1.controllers.playlist_entitlements_controller\
    import PlaylistEntitlementsController
from zypev1.controllers.subscription_entitlements_controller\
    import SubscriptionEntitlementsController
from zypev1.controllers.subscriptions_controller import SubscriptionsController
from zypev1.controllers.plans_controller import PlansController
from zypev1.controllers.transactions_controller import TransactionsController
from zypev1.controllers.redemption_codes_controller\
    import RedemptionCodesController
from zypev1.controllers.ad_tags_controller import AdTagsController
from zypev1.controllers.revenue_models_controller\
    import RevenueModelsController
from zypev1.controllers.video_favorites_controller\
    import VideoFavoritesController
from zypev1.controllers.zobject_types_controller import ZobjectTypesController
from zypev1.controllers.zobject_controller import ZobjectController


class Zypev1Client(object):

    @lazy_property
    def videos(self):
        return VideosController(self.config)

    @lazy_property
    def playlists(self):
        return PlaylistsController(self.config)

    @lazy_property
    def managing_playlist_relationships(self):
        return ManagingPlaylistRelationshipsController(self.config)

    @lazy_property
    def categories(self):
        return CategoriesController(self.config)

    @lazy_property
    def apps(self):
        return AppsController(self.config)

    @lazy_property
    def devices(self):
        return DevicesController(self.config)

    @lazy_property
    def device_categories(self):
        return DeviceCategoriesController(self.config)

    @lazy_property
    def players(self):
        return PlayersController(self.config)

    @lazy_property
    def master_manifests(self):
        return MasterManifestsController(self.config)

    @lazy_property
    def segments(self):
        return SegmentsController(self.config)

    @lazy_property
    def video_imports(self):
        return VideoImportsController(self.config)

    @lazy_property
    def video_sources(self):
        return VideoSourcesController(self.config)

    @lazy_property
    def category_content_rules(self):
        return CategoryContentRulesController(self.config)

    @lazy_property
    def playlist_content_rules(self):
        return PlaylistContentRulesController(self.config)

    @lazy_property
    def video_content_rules(self):
        return VideoContentRulesController(self.config)

    @lazy_property
    def consumers(self):
        return ConsumersController(self.config)

    @lazy_property
    def device_linking(self):
        return DeviceLinkingController(self.config)

    @lazy_property
    def o_auth(self):
        return OAuthController(self.config)

    @lazy_property
    def video_entitlements(self):
        return VideoEntitlementsController(self.config)

    @lazy_property
    def playlist_entitlements(self):
        return PlaylistEntitlementsController(self.config)

    @lazy_property
    def subscription_entitlements(self):
        return SubscriptionEntitlementsController(self.config)

    @lazy_property
    def subscriptions(self):
        return SubscriptionsController(self.config)

    @lazy_property
    def plans(self):
        return PlansController(self.config)

    @lazy_property
    def transactions(self):
        return TransactionsController(self.config)

    @lazy_property
    def redemption_codes(self):
        return RedemptionCodesController(self.config)

    @lazy_property
    def ad_tags(self):
        return AdTagsController(self.config)

    @lazy_property
    def revenue_models(self):
        return RevenueModelsController(self.config)

    @lazy_property
    def video_favorites(self):
        return VideoFavoritesController(self.config)

    @lazy_property
    def zobject_types(self):
        return ZobjectTypesController(self.config)

    @lazy_property
    def zobject(self):
        return ZobjectController(self.config)

    def __init__(self, http_client_instance=None,
                 override_http_client_configuration=False, timeout=60,
                 max_retries=0, backoff_factor=2,
                 retry_statuses=[408, 413, 429, 500, 502, 503, 504, 521, 522, 524],
                 retry_methods=['GET', 'PUT'],
                 environment=Environment.PRODUCTION, config=None):
        if config is None:
            self.config = Configuration(
                                         http_client_instance=http_client_instance,
                                         override_http_client_configuration=override_http_client_configuration,
                                         timeout=timeout,
                                         max_retries=max_retries,
                                         backoff_factor=backoff_factor,
                                         retry_statuses=retry_statuses,
                                         retry_methods=retry_methods,
                                         environment=environment)
        else:
            self.config = config



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.content_rule_metadata import ContentRuleMetadata


class CategoryContentRulesController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(CategoryContentRulesController, self).__init__(config, call_back)

    def categories_content_rules_by_category_id_get(self,
                                                    category_id):
        """Does a GET request to /categories/{category_id}/content_rules.

        List Content Rules for a Category

        Args:
            category_id (string): category ID

        Returns:
            list of ContentRuleMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/categories/{category_id}/content_rules'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'category_id': {'value': category_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ContentRuleMetadata.from_dictionary)

        return decoded

    def categories_content_rules_by_category_id_post(self,
                                                     body,
                                                     category_id):
        """Does a POST request to /categories/{category_id}/content_rules.

        Create Category Content Rule

        Args:
            body (ContentRuleRequest): TODO: type description here.
            category_id (string): TODO: type description here.

        Returns:
            ContentRuleMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/categories/{category_id}/content_rules'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'category_id': {'value': category_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ContentRuleMetadata.from_dictionary)

        return decoded

    def categories_content_rules_by_category_id_and_id_get(self,
                                                           category_id,
                                                           id):
        """Does a GET request to /categories/{category_id}/content_rules/{id}.

        View Category Content Rule

        Args:
            category_id (string): category ID
            id (string): content rule ID

        Returns:
            ContentRuleMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/categories/{category_id}/content_rules/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'category_id': {'value': category_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ContentRuleMetadata.from_dictionary)

        return decoded

    def categories_content_rules_by_category_id_and_id_put(self,
                                                           category_id,
                                                           id,
                                                           body):
        """Does a PUT request to /categories/{category_id}/content_rules/{id}.

        Update Category Content Rule

        Args:
            category_id (string): category ID
            id (string): content rule ID
            body (ContentRuleRequest): TODO: type description here.

        Returns:
            ContentRuleMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/categories/{category_id}/content_rules/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'category_id': {'value': category_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ContentRuleMetadata.from_dictionary)

        return decoded

    def categories_content_rules_by_category_id_and_id_delete(self,
                                                              category_id,
                                                              id):
        """Does a DELETE request to /categories/{category_id}/content_rules/{id}.

        Delete Category Content Rule

        Args:
            category_id (string): category ID
            id (string): content rule ID

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/categories/{category_id}/content_rules/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'category_id': {'value': category_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Image(object):

    """Implementation of the 'Image' model.

    TODO: type model description here.

    Attributes:
        id (string): ID of the image
        caption (string): Caption of the image
        title (string): Title of the image
        updated_at (string): Timestamp the image was updated
        url (string): URL where the image is hosted

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "caption": 'caption',
        "title": 'title',
        "updated_at": 'updated_at',
        "url": 'url'
    }

    def __init__(self,
                 id=None,
                 caption=None,
                 title=None,
                 updated_at=None,
                 url=None):
        """Constructor for the Image class"""

        # Initialize members of the class
        self.id = id
        self.caption = caption
        self.title = title
        self.updated_at = updated_at
        self.url = url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        caption = dictionary.get('caption')
        title = dictionary.get('title')
        updated_at = dictionary.get('updated_at')
        url = dictionary.get('url')

        # Return an object of this model
        return cls(id,
                   caption,
                   title,
                   updated_at,
                   url)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Consumer(object):

    """Implementation of the 'Consumer' model.

    TODO: type model description here.

    Attributes:
        email (string): TODO: type description here.
        name (string): TODO: type description here.
        sex (string): female
        birthday (string): 1997-07-17
        updates (bool): If the consumer has agreed to receive updates
        terms (bool): If consumer has agreed to the terms and services
        stripe_id (string): Unique ID assigned to the consumer in Stripe
        braintree_id (string): Unique ID assigned to the consumer in
            Braintree
        rss_token_x_0_f_lynw_9538_di_pbq_r_74_6_g_mn_tjmbpu_fr_sh_p_ne_eg_zt_o_
            kgz_x_qkt_z_0_k_jtqv_opcy_w (string): Unique token to identify a
            customer accessing your RSS feed
        password_token (string): The password token to use during password
            reset workflows
        remember_token (string): The password token to use during remember
            login workflows

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "email": 'email',
        "name": 'name',
        "sex": 'sex',
        "birthday": 'birthday',
        "updates": 'updates',
        "terms": 'terms',
        "stripe_id": 'stripe_id',
        "braintree_id": 'braintree_id',
        "rss_token_x_0_f_lynw_9538_di_pbq_r_74_6_g_mn_tjmbpu_fr_sh_p_ne_eg_zt_o_kgz_x_qkt_z_0_k_jtqv_opcy_w": 'rss_token: X0fLYNW9538DiPbqR74-6gMnTjmbpuFrShP-NeEgZtOKgzXQktZ0KJtqvOPCY_w_',
        "password_token": 'password_token',
        "remember_token": 'remember_token'
    }

    def __init__(self,
                 email=None,
                 name=None,
                 sex=None,
                 birthday=None,
                 updates=None,
                 terms=None,
                 stripe_id=None,
                 braintree_id=None,
                 rss_token_x_0_f_lynw_9538_di_pbq_r_74_6_g_mn_tjmbpu_fr_sh_p_ne_eg_zt_o_kgz_x_qkt_z_0_k_jtqv_opcy_w=None,
                 password_token=None,
                 remember_token=None):
        """Constructor for the Consumer class"""

        # Initialize members of the class
        self.email = email
        self.name = name
        self.sex = sex
        self.birthday = birthday
        self.updates = updates
        self.terms = terms
        self.stripe_id = stripe_id
        self.braintree_id = braintree_id
        self.rss_token_x_0_f_lynw_9538_di_pbq_r_74_6_g_mn_tjmbpu_fr_sh_p_ne_eg_zt_o_kgz_x_qkt_z_0_k_jtqv_opcy_w = rss_token_x_0_f_lynw_9538_di_pbq_r_74_6_g_mn_tjmbpu_fr_sh_p_ne_eg_zt_o_kgz_x_qkt_z_0_k_jtqv_opcy_w
        self.password_token = password_token
        self.remember_token = remember_token

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        email = dictionary.get('email')
        name = dictionary.get('name')
        sex = dictionary.get('sex')
        birthday = dictionary.get('birthday')
        updates = dictionary.get('updates')
        terms = dictionary.get('terms')
        stripe_id = dictionary.get('stripe_id')
        braintree_id = dictionary.get('braintree_id')
        rss_token_x_0_f_lynw_9538_di_pbq_r_74_6_g_mn_tjmbpu_fr_sh_p_ne_eg_zt_o_kgz_x_qkt_z_0_k_jtqv_opcy_w = dictionary.get('rss_token: X0fLYNW9538DiPbqR74-6gMnTjmbpuFrShP-NeEgZtOKgzXQktZ0KJtqvOPCY_w_')
        password_token = dictionary.get('password_token')
        remember_token = dictionary.get('remember_token')

        # Return an object of this model
        return cls(email,
                   name,
                   sex,
                   birthday,
                   updates,
                   terms,
                   stripe_id,
                   braintree_id,
                   rss_token_x_0_f_lynw_9538_di_pbq_r_74_6_g_mn_tjmbpu_fr_sh_p_ne_eg_zt_o_kgz_x_qkt_z_0_k_jtqv_opcy_w,
                   password_token,
                   remember_token)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AddZobjectSToVideoRequest(object):

    """Implementation of the 'Add Zobject(s) to Video request' model.

    TODO: type model description here.

    Attributes:
        zobject_id (object): Zobject IDs to be added

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "zobject_id": 'zobject_id'
    }

    def __init__(self,
                 zobject_id=None):
        """Constructor for the AddZobjectSToVideoRequest class"""

        # Initialize members of the class
        self.zobject_id = zobject_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        zobject_id = dictionary.get('zobject_id')

        # Return an object of this model
        return cls(zobject_id)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ZobjectType(object):

    """Implementation of the 'ZobjectType' model.

    TODO: type model description here.

    Attributes:
        description (string): Description of the Zobject Type
        title (string): Title of the Zobject Type (must be unique)
        videos_enabled (bool): Indicates whether videos can be associated with
            instances of the Zobject Type

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "description": 'description',
        "title": 'title',
        "videos_enabled": 'videos_enabled'
    }

    def __init__(self,
                 description=None,
                 title=None,
                 videos_enabled=None):
        """Constructor for the ZobjectType class"""

        # Initialize members of the class
        self.description = description
        self.title = title
        self.videos_enabled = videos_enabled

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        description = dictionary.get('description')
        title = dictionary.get('title')
        videos_enabled = dictionary.get('videos_enabled')

        # Return an object of this model
        return cls(description,
                   title,
                   videos_enabled)



__all__ = [
    'base_controller',
    'videos_controller',
    'playlists_controller',
    'managing_playlist_relationships_controller',
    'categories_controller',
    'apps_controller',
    'devices_controller',
    'device_categories_controller',
    'players_controller',
    'master_manifests_controller',
    'segments_controller',
    'video_imports_controller',
    'video_sources_controller',
    'category_content_rules_controller',
    'playlist_content_rules_controller',
    'video_content_rules_controller',
    'consumers_controller',
    'device_linking_controller',
    'o_auth_controller',
    'video_entitlements_controller',
    'playlist_entitlements_controller',
    'subscription_entitlements_controller',
    'subscriptions_controller',
    'plans_controller',
    'transactions_controller',
    'redemption_codes_controller',
    'ad_tags_controller',
    'revenue_models_controller',
    'video_favorites_controller',
    'zobject_types_controller',
    'zobject_controller',
]



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OAuthRefreshRequest(object):

    """Implementation of the 'OAuthRefreshRequest' model.

    TODO: type model description here.

    Attributes:
        client_id (string): The client ID for your Zype application
        client_secret (string): The client secret for your Zype application
        refresh_token (string): Token to use to refresh
        grant_type (string): Use `refresh_token`. Required for access token
            refresh.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": 'client_id',
        "client_secret": 'client_secret',
        "refresh_token": 'refresh_token',
        "grant_type": 'grant_type'
    }

    def __init__(self,
                 client_id=None,
                 client_secret=None,
                 refresh_token=None,
                 grant_type=None):
        """Constructor for the OAuthRefreshRequest class"""

        # Initialize members of the class
        self.client_id = client_id
        self.client_secret = client_secret
        self.refresh_token = refresh_token
        self.grant_type = grant_type

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id = dictionary.get('client_id')
        client_secret = dictionary.get('client_secret')
        refresh_token = dictionary.get('refresh_token')
        grant_type = dictionary.get('grant_type')

        # Return an object of this model
        return cls(client_id,
                   client_secret,
                   refresh_token,
                   grant_type)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.redemption_code_metadata import RedemptionCodeMetadata


class RedemptionCodesController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(RedemptionCodesController, self).__init__(config, call_back)

    def redemption_codes_get(self,
                             code,
                             id=None,
                             created_at=None,
                             updated_at=None,
                             expiration_date=None,
                             redeemed_at=None,
                             pass_plan_id=None,
                             plan_id=None,
                             playlist_id=None,
                             transaction_id=None,
                             video_id=None,
                             q=None,
                             order=None,
                             sort=None,
                             page=None,
                             per_page=None,
                             api_key=None):
        """Does a GET request to /redemption_codes.

        List Redemption Codes

        Args:
            code (string): Filter by code
            id (string, optional): Filter by ID + Examples     +
                `id=59b2ffaac8a589000100001b`     + use
                `id!=59b2ffaac8a589000100001b` to exclude by ID
            created_at (date, optional): Filter by created at date using times
                in ISO8601 format Note: Range filters can be applied by adding
                a suffix: ‘.gt’, ‘.gte’, ‘.lt’, ‘lte’ (Example:
                expires_at.gte) + Examples     + `2017-01-01T00:00:00-00:00` -
                in ISO8601 format     + `1483228800` - Unix timestamps
            updated_at (date, optional): Filter by created at date using times
                in ISO8601 format Note: Range filters can be applied by adding
                a suffix: ‘.gt’, ‘.gte’, ‘.lt’, ‘lte’ (Example:
                expires_at.gte) + Examples     + `2017-01-01T00:00:00-00:00` -
                in ISO8601 format     + `1483228800` - Unix timestamps
            expiration_date (date, optional): Filter by created at date using
                times in ISO8601 format Note: Range filters can be applied by
                adding a suffix: ‘.gt’, ‘.gte’, ‘.lt’, ‘lte’ (Example:
                expires_at.gte) + Examples     + `2017-01-01T00:00:00-00:00` -
                in ISO8601 format     + `1483228800` - Unix timestamps
            redeemed_at (date, optional): Filter by created at date using
                times in ISO8601 format Note: Range filters can be applied by
                adding a suffix: ‘.gt’, ‘.gte’, ‘.lt’, ‘lte’ (Example:
                expires_at.gte) + Examples     + `2017-01-01T00:00:00-00:00` -
                in ISO8601 format     + `1483228800` - Unix timestamps
            pass_plan_id (string, optional): Filter records by a pass plan ID
            plan_id (string, optional): Filter records by plan ID
            playlist_id (string, optional): Filter records by playlist ID
            transaction_id (string, optional): Filter records by transaction
                ID
            video_id (string, optional): Filter records by video ID
            q (string, optional): Filter by keyword
            order (string, optional): Filter by ascending or descending order
                + Examples     + asc     + desc
            sort (string, optional): Sort on the specified field
            page (float, optional): Number of pages to return
            per_page (float, optional): Number of records to return per page
            api_key (string, optional): TODO: type description here.

        Returns:
            RedemptionCodeMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/redemption_codes'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'code': code,
            'id': id,
            'created_at': created_at,
            'updated_at': updated_at,
            'expiration_date': expiration_date,
            'redeemed_at': redeemed_at,
            'pass_plan_id': pass_plan_id,
            'plan_id': plan_id,
            'playlist_id': playlist_id,
            'transaction_id': transaction_id,
            'video_id': video_id,
            'q': q,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page,
            'api_key': api_key
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, RedemptionCodeMetadata.from_dictionary)

        return decoded

    def redemption_codes_post(self,
                              body,
                              id=None,
                              api_key=None,
                              code=None,
                              created_at=None,
                              expiration_date=None,
                              pass_plan_id=None,
                              plan_id=None,
                              playlist_id=None,
                              redeemed_at=None,
                              transaction_id=None,
                              updated_at=None,
                              video_id=None,
                              order=None,
                              sort=None,
                              page=None,
                              per_page=None,
                              q=None):
        """Does a POST request to /redemption_codes.

        Create Redemption Codes

        Args:
            body (RedemptionCodeRequest): TODO: type description here.
            id (string, optional): TODO: type description here.
            api_key (string, optional): TODO: type description here.
            code (string, optional): TODO: type description here.
            created_at (string, optional): TODO: type description here.
            expiration_date (string, optional): TODO: type description here.
            pass_plan_id (string, optional): TODO: type description here.
            plan_id (string, optional): TODO: type description here.
            playlist_id (string, optional): TODO: type description here.
            redeemed_at (string, optional): TODO: type description here.
            transaction_id (string, optional): TODO: type description here.
            updated_at (string, optional): TODO: type description here.
            video_id (string, optional): TODO: type description here.
            order (string, optional): TODO: type description here.
            sort (string, optional): TODO: type description here.
            page (string, optional): TODO: type description here.
            per_page (string, optional): TODO: type description here.
            q (string, optional): TODO: type description here.

        Returns:
            RedemptionCodeMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/redemption_codes'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'id': id,
            'api_key': api_key,
            'code': code,
            'created_at': created_at,
            'expiration_date': expiration_date,
            'pass_plan_id': pass_plan_id,
            'plan_id': plan_id,
            'playlist_id': playlist_id,
            'redeemed_at': redeemed_at,
            'transaction_id': transaction_id,
            'updated_at': updated_at,
            'video_id': video_id,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page,
            'q': q
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, RedemptionCodeMetadata.from_dictionary)

        return decoded

    def redemption_codes_by_id_get(self,
                                   id):
        """Does a GET request to /redemption_codes/{id}.

        View Redemption Code

        Args:
            id (string): ID of the redemption code

        Returns:
            RedemptionCodeMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/redemption_codes/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, RedemptionCodeMetadata.from_dictionary)

        return decoded

    def redemption_codes_by_id_put(self,
                                   id,
                                   body):
        """Does a PUT request to /redemption_codes/{id}.

        Update Redemption Code

        Args:
            id (string): ID of the redemption code
            body (RedemptionCodeRequest): TODO: type description here.

        Returns:
            RedemptionCodeMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/redemption_codes/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, RedemptionCodeMetadata.from_dictionary)

        return decoded

    def redemption_codes_by_id_delete(self,
                                      id):
        """Does a DELETE request to /redemption_codes/{id}.

        Delete Redemption Code

        Args:
            id (string): ID of the redemption code

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/redemption_codes/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VideoManifest(object):

    """Implementation of the 'VideoManifest' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        url (string):
            api.us-east-1.amazonaws.com/latest/eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1
            NiJ9.eyJhZF91cmwiOiJodHRwczovL3p5cGVsaXZlLWxoLmFrYW1haWhkLXN0YWdpbm
            cubmV0L2kvZGVmYXVsdF8xQEFzdGFjb21tL21hc3Rlci5tM3U4P3N0YXJ0PTE1MDc1N
            jE3MjkmaGRudHM9ZXhwJTNEMTUwODUzNTMxNSU3RWFjbCUzRCUyRiolNDBBc3RhY29t
            bSUyRiolN0VobWFjJTNENjhjMDU2MjRjNzQ0YzY4MWUyNDQ2YjcyZGFjYzllN2U1MWN
            hYTA5ZWRjZjgyNTk5ZTUwYzI0MmQ2ZjQzMWQ2MSIsInZpZGVvX2lkIjoiNTlkYjkxMW
            Y2ZTgyYzIwMDAxMDAwMDBlIiwic2l0ZV9pZCI6IjU5ODMzMmVlODExMzc4MDAwMTAwM
            DBlNyIsImRhdGUiOiIyMDE3LTEwLTE5VDIxOjM1OjE1KzAwOjAwIiwiZW52Ijoic3Rh
            Z2UifQ.v2H5T5BHO5jYFE2AQ1TW7EP33624up7oM3KuNOg6BBY

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "url": 'url'
    }

    def __init__(self,
                 id=None,
                 url=None):
        """Constructor for the VideoManifest class"""

        # Initialize members of the class
        self.id = id
        self.url = url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        url = dictionary.get('url')

        # Return an object of this model
        return cls(id,
                   url)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PlanMetadata(object):

    """Implementation of the 'PlanMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        active (string): TODO: type description here.
        amount (string): TODO: type description here.
        created_at (string): TODO: type description here.
        currency (string): TODO: type description here.
        description (string): TODO: type description here.
        interval (string): TODO: type description here.
        name (string): TODO: type description here.
        stripe_id (string): monthly
        stripe_public_key (string): TODO: type description here.
        trial_period_days (string): TODO: type description here.
        updated_at (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "active": 'active',
        "amount": 'amount',
        "created_at": 'created_at',
        "currency": 'currency',
        "description": 'description',
        "interval": 'interval',
        "name": 'name',
        "stripe_id": 'stripe_id',
        "stripe_public_key": 'stripe_public_key',
        "trial_period_days": 'trial_period_days',
        "updated_at": 'updated_at'
    }

    def __init__(self,
                 id=None,
                 active=None,
                 amount=None,
                 created_at=None,
                 currency=None,
                 description=None,
                 interval=None,
                 name=None,
                 stripe_id=None,
                 stripe_public_key=None,
                 trial_period_days=None,
                 updated_at=None):
        """Constructor for the PlanMetadata class"""

        # Initialize members of the class
        self.id = id
        self.active = active
        self.amount = amount
        self.created_at = created_at
        self.currency = currency
        self.description = description
        self.interval = interval
        self.name = name
        self.stripe_id = stripe_id
        self.stripe_public_key = stripe_public_key
        self.trial_period_days = trial_period_days
        self.updated_at = updated_at

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        active = dictionary.get('active')
        amount = dictionary.get('amount')
        created_at = dictionary.get('created_at')
        currency = dictionary.get('currency')
        description = dictionary.get('description')
        interval = dictionary.get('interval')
        name = dictionary.get('name')
        stripe_id = dictionary.get('stripe_id')
        stripe_public_key = dictionary.get('stripe_public_key')
        trial_period_days = dictionary.get('trial_period_days')
        updated_at = dictionary.get('updated_at')

        # Return an object of this model
        return cls(id,
                   active,
                   amount,
                   created_at,
                   currency,
                   description,
                   interval,
                   name,
                   stripe_id,
                   stripe_public_key,
                   trial_period_days,
                   updated_at)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.consumer_metadata import ConsumerMetadata


class ConsumersController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(ConsumersController, self).__init__(config, call_back)

    def consumers_get(self,
                      braintree_id=None,
                      stripe_id=None,
                      email=None,
                      password_token=None,
                      rss_token=None,
                      id=None,
                      created_at=None,
                      q=None,
                      order=None,
                      sort=None,
                      page=None,
                      per_page=None):
        """Does a GET request to /consumers.

        List Consumers

        Args:
            braintree_id (string, optional): Filter by the consumer's
                Braintree ID
            stripe_id (string, optional): Filter by the consumer's Stripe ID
            email (string, optional): Filter by the consumer's email
            password_token (string, optional): Filter by the consumer's
                password token
            rss_token (string, optional): Filter by the consumer's RSS token
            id (string, optional): Filter by id + Examples     +
                `id=5992f328ce593000ef000008`     + use
                `id!=5992f328ce593000ef000008` to exclude by id
            created_at (string, optional): Filter by when consumer was
                created
            q (string, optional): Filter by keyword
            order (string, optional): Filter by ascending or descending order
                + Examples     + `asc`     + `desc`
            sort (string, optional): Sort on the specified field
            page (float, optional): Number of pages to return
            per_page (float, optional): Number of records to return per page

        Returns:
            list of ConsumerMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'braintree_id': braintree_id,
            'stripe_id': stripe_id,
            'email': email,
            'password_token': password_token,
            'rss_token': rss_token,
            'id': id,
            'created_at': created_at,
            'q': q,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ConsumerMetadata.from_dictionary)

        return decoded

    def consumers_post(self,
                       body,
                       braintree_id=None,
                       stripe_id=None,
                       created_at=None,
                       email=None,
                       id=None,
                       password_token=None,
                       rss_token=None,
                       page=None,
                       per_page=None,
                       order=None,
                       sort=None,
                       q=None):
        """Does a POST request to /consumers.

        Create Consumers

        Args:
            body (ConsumerRequest): TODO: type description here.
            braintree_id (string, optional): TODO: type description here.
            stripe_id (string, optional): TODO: type description here.
            created_at (string, optional): TODO: type description here.
            email (string, optional): TODO: type description here.
            id (string, optional): TODO: type description here.
            password_token (string, optional): TODO: type description here.
            rss_token (string, optional): TODO: type description here.
            page (string, optional): TODO: type description here.
            per_page (string, optional): TODO: type description here.
            order (string, optional): TODO: type description here.
            sort (string, optional): TODO: type description here.
            q (string, optional): TODO: type description here.

        Returns:
            ConsumerMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'braintree_id': braintree_id,
            'stripe_id': stripe_id,
            'created_at': created_at,
            'email': email,
            'id': id,
            'password_token': password_token,
            'rss_token': rss_token,
            'page': page,
            'per_page': per_page,
            'order': order,
            'sort': sort,
            'q': q
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ConsumerMetadata.from_dictionary)

        return decoded

    def consumers_by_id_get(self,
                            id):
        """Does a GET request to /consumers/{id}.

        View Consumer

        Args:
            id (string): Consumer ID

        Returns:
            ConsumerMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ConsumerMetadata.from_dictionary)

        return decoded

    def consumers_by_id_put(self,
                            id,
                            body):
        """Does a PUT request to /consumers/{id}.

        Update Consumer

        Args:
            id (string): Consumer ID
            body (ConsumerRequest): TODO: type description here.

        Returns:
            ConsumerMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ConsumerMetadata.from_dictionary)

        return decoded

    def consumers_by_id_delete(self,
                               id):
        """Does a DELETE request to /consumers/{id}.

        Delete Video Consumer

        Args:
            id (string): Consumer ID

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Entitlement(object):

    """Implementation of the 'entitlement' model.

    TODO: type model description here.

    Attributes:
        expires_at (string): TODO: type description here.
        transaction_id (string): TODO: type description here.
        transaction_type (string): TODO: type description here.
        video_id (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "expires_at": 'expires_at',
        "transaction_id": 'transaction_id',
        "transaction_type": 'transaction_type',
        "video_id": 'video_id'
    }

    def __init__(self,
                 expires_at=None,
                 transaction_id=None,
                 transaction_type=None,
                 video_id=None):
        """Constructor for the Entitlement class"""

        # Initialize members of the class
        self.expires_at = expires_at
        self.transaction_id = transaction_id
        self.transaction_type = transaction_type
        self.video_id = video_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        expires_at = dictionary.get('expires_at')
        transaction_id = dictionary.get('transaction_id')
        transaction_type = dictionary.get('transaction_type')
        video_id = dictionary.get('video_id')

        # Return an object of this model
        return cls(expires_at,
                   transaction_id,
                   transaction_type,
                   video_id)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class DevicePin(object):

    """Implementation of the 'DevicePin' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        consumer_id (string): TODO: type description here.
        created_at (string): TODO: type description here.
        deleted_at (string): TODO: type description here.
        linked_device_id (string): TODO: type description here.
        pin (string): TODO: type description here.
        pin_expiration (string): 02-13T07:27:00.113-05:00
        updated_at (string): TODO: type description here.
        linked_true (bool): TODO: type description here.
        subscription_count (float): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "consumer_id": 'consumer_id',
        "created_at": 'created_at',
        "deleted_at": 'deleted_at',
        "linked_device_id": 'linked_device_id',
        "pin": 'pin',
        "pin_expiration": 'pin_expiration',
        "updated_at": 'updated_at',
        "linked_true": 'linked true',
        "subscription_count": 'subscription_count'
    }

    def __init__(self,
                 id=None,
                 consumer_id=None,
                 created_at=None,
                 deleted_at=None,
                 linked_device_id=None,
                 pin=None,
                 pin_expiration=None,
                 updated_at=None,
                 linked_true=None,
                 subscription_count=None):
        """Constructor for the DevicePin class"""

        # Initialize members of the class
        self.id = id
        self.consumer_id = consumer_id
        self.created_at = created_at
        self.deleted_at = deleted_at
        self.linked_device_id = linked_device_id
        self.pin = pin
        self.pin_expiration = pin_expiration
        self.updated_at = updated_at
        self.linked_true = linked_true
        self.subscription_count = subscription_count

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        consumer_id = dictionary.get('consumer_id')
        created_at = dictionary.get('created_at')
        deleted_at = dictionary.get('deleted_at')
        linked_device_id = dictionary.get('linked_device_id')
        pin = dictionary.get('pin')
        pin_expiration = dictionary.get('pin_expiration')
        updated_at = dictionary.get('updated_at')
        linked_true = dictionary.get('linked true')
        subscription_count = dictionary.get('subscription_count')

        # Return an object of this model
        return cls(id,
                   consumer_id,
                   created_at,
                   deleted_at,
                   linked_device_id,
                   pin,
                   pin_expiration,
                   updated_at,
                   linked_true,
                   subscription_count)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from zypev1.models.embedded_category import EmbeddedCategory
from zypev1.models.image import Image
from zypev1.models.sort_option import SortOption
from zypev1.models.thumbnail import Thumbnail


class PlaylistMetadata(object):

    """Implementation of the 'PlaylistMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): ID of the record
        keywords (list of string): Keywords for a playlist
        created_at (string): Timestamp playlist was created
        deleted_at (string): Timestamp playlist was deleted
        updated_at (string): Timestamp of when video was last updated
        discovery_url (string): URL where you playlist can be discovered
        playlist_item_count (float): Number of videos in a playlist
        thumbnails (list of Thumbnail): TODO: type description here.
        active (bool): Whether or not the playlist is active true
        auto_remove_video_entitlements (bool): Automatically remove a
            customer's entitlement to view a video if it is removed from the
            playlist
        auto_update_video_entitlements (bool): Automatically update a
            customer's entitlement to view a video if it is added to the
            playlist
        description (string): Description of the playlist
        friendly_title (string): The URL friendly title of the playlist
        title (string): Title of the playlist
        playlist_type (string): Determine if videos will automatically be
            added to this playlist based off the category values assigned to
            them. If you would like this feature, set to 'category',
            otherwise, set to 'manual' to disable. If enabled, you may not
            manually add videos to this playlist. Options are: - manual -
            category
        match_type (string): Used to specify matching categories to a playlist
            by ALL category values or ANY category values - any - all
        parent_id (string): The parent playlist id. If this value is null, the
            playlist is a root playlist and can be used as the primary
            playlist within an app where all your other playlists and videos
            are nested under
        priority (float): The priority of the playlist related with its
            siblings. Playlists are ordered ascending by priority value
        purchase_price (float): Amount to purchase the playlist bundle
        purchase_required (bool): Whether or not the playlist must be
            purchased
        rental_duration (float): Number of days a playlist bundle can be
            rented
        rental_price (float): Price to rent the playlist bundle
        rental_required (bool): Whether or not the playlist bundle must be
            rented
        thumnbail_layout (string): Orientation of the playlist thumbnail
            Layout must be one of:     + landscape     + poster     + square
        site_id (string): Site the playlist is related to
        video_ids (object): IDs of videos that are associated with Playlist
        images (list of Image): TODO: type description here.
        categories (list of EmbeddedCategory): TODO: type description here.
        sort_options (list of SortOption): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "keywords": '_keywords',
        "created_at": 'created_at',
        "deleted_at": 'deleted_at',
        "updated_at": 'updated_at',
        "discovery_url": 'discovery_url',
        "playlist_item_count": 'playlist_item_count',
        "thumbnails": 'thumbnails',
        "active": 'active',
        "auto_remove_video_entitlements": 'auto_remove_video_entitlements',
        "auto_update_video_entitlements": 'auto_update_video_entitlements',
        "description": 'description',
        "friendly_title": 'friendly_title',
        "title": 'title',
        "playlist_type": 'playlist_type',
        "match_type": 'match_type',
        "parent_id": 'parent_id',
        "priority": 'priority',
        "purchase_price": 'purchase_price',
        "purchase_required": 'purchase_required',
        "rental_duration": 'rental_duration',
        "rental_price": 'rental_price',
        "rental_required": 'rental_required',
        "thumnbail_layout": 'thumnbail_layout',
        "site_id": 'site_id',
        "video_ids": 'video_ids',
        "images": 'images',
        "categories": 'categories',
        "sort_options": 'sort_options'
    }

    def __init__(self,
                 id=None,
                 keywords=None,
                 created_at=None,
                 deleted_at=None,
                 updated_at=None,
                 discovery_url=None,
                 playlist_item_count=None,
                 thumbnails=None,
                 active=None,
                 auto_remove_video_entitlements=None,
                 auto_update_video_entitlements=None,
                 description=None,
                 friendly_title=None,
                 title=None,
                 playlist_type=None,
                 match_type=None,
                 parent_id=None,
                 priority=None,
                 purchase_price=None,
                 purchase_required=None,
                 rental_duration=None,
                 rental_price=None,
                 rental_required=None,
                 thumnbail_layout=None,
                 site_id=None,
                 video_ids=None,
                 images=None,
                 categories=None,
                 sort_options=None):
        """Constructor for the PlaylistMetadata class"""

        # Initialize members of the class
        self.id = id
        self.keywords = keywords
        self.created_at = created_at
        self.deleted_at = deleted_at
        self.updated_at = updated_at
        self.discovery_url = discovery_url
        self.playlist_item_count = playlist_item_count
        self.thumbnails = thumbnails
        self.active = active
        self.auto_remove_video_entitlements = auto_remove_video_entitlements
        self.auto_update_video_entitlements = auto_update_video_entitlements
        self.description = description
        self.friendly_title = friendly_title
        self.title = title
        self.playlist_type = playlist_type
        self.match_type = match_type
        self.parent_id = parent_id
        self.priority = priority
        self.purchase_price = purchase_price
        self.purchase_required = purchase_required
        self.rental_duration = rental_duration
        self.rental_price = rental_price
        self.rental_required = rental_required
        self.thumnbail_layout = thumnbail_layout
        self.site_id = site_id
        self.video_ids = video_ids
        self.images = images
        self.categories = categories
        self.sort_options = sort_options

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        keywords = dictionary.get('_keywords')
        created_at = dictionary.get('created_at')
        deleted_at = dictionary.get('deleted_at')
        updated_at = dictionary.get('updated_at')
        discovery_url = dictionary.get('discovery_url')
        playlist_item_count = dictionary.get('playlist_item_count')
        thumbnails = None
        if dictionary.get('thumbnails') is not None:
            thumbnails = [Thumbnail.from_dictionary(x) for x in dictionary.get('thumbnails')]
        active = dictionary.get('active')
        auto_remove_video_entitlements = dictionary.get('auto_remove_video_entitlements')
        auto_update_video_entitlements = dictionary.get('auto_update_video_entitlements')
        description = dictionary.get('description')
        friendly_title = dictionary.get('friendly_title')
        title = dictionary.get('title')
        playlist_type = dictionary.get('playlist_type')
        match_type = dictionary.get('match_type')
        parent_id = dictionary.get('parent_id')
        priority = dictionary.get('priority')
        purchase_price = dictionary.get('purchase_price')
        purchase_required = dictionary.get('purchase_required')
        rental_duration = dictionary.get('rental_duration')
        rental_price = dictionary.get('rental_price')
        rental_required = dictionary.get('rental_required')
        thumnbail_layout = dictionary.get('thumnbail_layout')
        site_id = dictionary.get('site_id')
        video_ids = dictionary.get('video_ids')
        images = None
        if dictionary.get('images') is not None:
            images = [Image.from_dictionary(x) for x in dictionary.get('images')]
        categories = None
        if dictionary.get('categories') is not None:
            categories = [EmbeddedCategory.from_dictionary(x) for x in dictionary.get('categories')]
        sort_options = None
        if dictionary.get('sort_options') is not None:
            sort_options = [SortOption.from_dictionary(x) for x in dictionary.get('sort_options')]

        # Return an object of this model
        return cls(id,
                   keywords,
                   created_at,
                   deleted_at,
                   updated_at,
                   discovery_url,
                   playlist_item_count,
                   thumbnails,
                   active,
                   auto_remove_video_entitlements,
                   auto_update_video_entitlements,
                   description,
                   friendly_title,
                   title,
                   playlist_type,
                   match_type,
                   parent_id,
                   priority,
                   purchase_price,
                   purchase_required,
                   rental_duration,
                   rental_price,
                   rental_required,
                   thumnbail_layout,
                   site_id,
                   video_ids,
                   images,
                   categories,
                   sort_options)
